//
//  AboutUsViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 12.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Present about us information
class AboutUsViewController: BaseViewController {

    weak var linkLabel: UILabel!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        self.setupGestureRecognizer()
    }

    override init() {
        super.init()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func loadView() {
        super.loadView()
        
        let logoImageView = UIImageView()
        logoImageView.image = #imageLiteral(resourceName: "czuLogo")
        self.view.addSubview(logoImageView)
        logoImageView.snp.makeConstraints { (make) in
            make.top.equalTo(view.safeAreaLayoutGuide.snp.top).offset(30)
            make.width.equalTo(150)
            make.height.equalTo(100)
            make.centerX.equalTo(view.snp.centerX)
        }
        
        let textLabel = UILabel()
        textLabel.textColor = UIColor.black
        textLabel.textAlignment = .center
        textLabel.numberOfLines = 0
        textLabel.font = UIFont.systemFont(ofSize: 20, weight: UIFont.Weight.regular)
        textLabel.text = "This project is related to practical part of master theses created by Tomáš Hamerník at Czech University of life science Prague"
        view.addSubview(textLabel)
        textLabel.snp.makeConstraints { (make) in
            make.leading.equalTo(24)
            make.trailing.equalTo(-24)
            make.top.equalTo(logoImageView.snp.bottom).offset(40)
        }
        
        let linkLabel = UILabel()
        linkLabel.textColor = UIColor.black
        linkLabel.textAlignment = .center
        linkLabel.numberOfLines = 0
        linkLabel.text = "University websites are avaliable here!"
        linkLabel.isUserInteractionEnabled = true
        linkLabel.font = UIFont.systemFont(ofSize: 16, weight: UIFont.Weight.medium)
        view.addSubview(linkLabel)
        linkLabel.snp.makeConstraints { (make) in
            make.top.equalTo(textLabel.snp.bottom).offset(40)
            make.leading.equalTo(24)
            make.trailing.equalTo(-24)
        }

        self.linkLabel = linkLabel
    }
    
    /// Create and add gesture recognizer to link label.
    func setupGestureRecognizer() {
        let gesture = UITapGestureRecognizer(target: self, action: #selector(self.openUrlAddress))
        self.linkLabel.addGestureRecognizer(gesture)
    }
    
    /// Open url at CZU address.
    @objc func openUrlAddress() {
        if let url = URL(string: "https://www.czu.cz") {
            UIApplication.shared.open(url, options: [:])
        }
    }

}
