//
//  BaseViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Super class for all controllers. Handle group setups
class BaseViewController: UIViewController {
    
    /// Print name of deinitialized controller and remove any observers from it if there is any.
    deinit {
        print("deinit \(self.description)")
        NotificationCenter.default.removeObserver(self)
    }

    // MARK: - Life cycle
    override func viewDidLoad() {
        super.viewDidLoad()
        self.view.backgroundColor = UIColor.init(color: .backgroundGray)
    }
    
    init() {
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    
    /// Methods for presenting error alert in controllers
    ///
    /// - Parameters:
    ///   - title: Title for the alert
    ///   - message: Message for the alert
    func presentCommonErrorAlert(with title: String, message: String) {
        let alert = UIAlertController(title: title, message: message, preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "Ok", style: .cancel, handler: nil))
        self.present(alert, animated: true, completion: nil)
    }
}
