//
//  DatePickerViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 10.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Controller for handling picking the date of next new vaccine record.
class DatePickerViewController: BaseViewController {
    
    // MARK: - UI Objects
    weak var confirmButon: RoundedButton!
    weak var cancelButton: RoundedButton!
    weak var datePicker: UIDatePicker!
    
    // MARK: - Properties
    weak var delegate: DatePickerViewControllerDelegate?
    
    // MARK: - Life cycle
    override init() {
        super.init()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
    
        self.view.backgroundColor = .clear
        
        self.cancelButton.addTarget(self, action: #selector(self.didPressDismissButton), for: .touchUpInside)
        self.confirmButon.addTarget(self, action: #selector(self.didPressConfirmButton), for: .touchUpInside)
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        
        UIView.animate(withDuration: 0.4) { [weak self] in
            self?.view.backgroundColor = UIColor.clear.withAlphaComponent(0.5)
        }
    }
    
    override func loadView() {
        super.loadView()
        
        let contentView = UIView()
        contentView.backgroundColor = .white
        self.view.addSubview(contentView)
        contentView.snp.makeConstraints { (make) in
            make.leading.trailing.bottom.equalTo(0)
            make.height.equalTo(240)
        }
        
        
        let confirmButtonAttributedText = NSAttributedString(string: "Confirm", attributes: [NSAttributedStringKey.font: UIFont.systemFont(ofSize: 15, weight: UIFont.Weight.bold), NSAttributedStringKey.foregroundColor: UIColor.white])
        let confirmButton = RoundedButton()
        confirmButton.backgroundColor = UIColor.init(color: .orangeff)
        confirmButton.setAttributedTitle(confirmButtonAttributedText, for: .normal)
        
        let cancelButtonAttributedText = NSAttributedString(string: "Cancel", attributes: [NSAttributedStringKey.font: UIFont.systemFont(ofSize: 15, weight: UIFont.Weight.bold), NSAttributedStringKey.foregroundColor: UIColor.white])
        let cancelButton = RoundedButton()
        cancelButton.backgroundColor = UIColor.init(color: .orangeff)
        cancelButton.setAttributedTitle(cancelButtonAttributedText, for: .normal)
        
        let stackView = UIStackView(arrangedSubviews: [cancelButton, confirmButton])
        stackView.spacing = 8
        stackView.axis = .horizontal
        stackView.distribution = .fillEqually
        
        contentView.addSubview(stackView)
        stackView.snp.makeConstraints { (make) in
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.bottom.equalTo(view.safeAreaLayoutGuide.snp.bottom).offset(-16)
        }
        
        confirmButton.snp.makeConstraints { (make) in
            make.height.equalTo(54)
        }
        
        cancelButton.snp.makeConstraints { (make) in
            make.height.equalTo(54)
        }
        
        self.cancelButton = cancelButton
        self.confirmButon = confirmButton
        
        
        let datePicker = UIDatePicker()
        datePicker.minimumDate = Date()
        datePicker.datePickerMode = .date
        contentView.addSubview(datePicker)
        datePicker.snp.makeConstraints { (make) in
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.bottom.equalTo(stackView.snp.top).offset(-16)
            make.height.equalTo(100)
        }
        self.datePicker = datePicker
    }
    
    // MARK: - Action methods
    /// Method for background animation
    private func animatedDismiss() {
        UIView.animate(withDuration: 0.4, animations: { [weak self] in
            self?.view.backgroundColor = UIColor.clear
        }) { (bool) in
            if bool {
                self.dismiss(animated: true, completion: nil)
            }
        }
    }
    
    /// Methods for dismissing controller with animation without picking any date
    @objc func didPressDismissButton() {
        self.animatedDismiss()
    }
    
    /// Method for confirming the selected date dismiss controller with animation
    @objc func didPressConfirmButton() {
        self.delegate?.didConfirmPick(with: self.datePicker.date)
        self.animatedDismiss()
    }
    
}
