//
//  GetStartedViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Controller for get started screen
class GetStartedViewController: BaseViewController {
    
    // MARK: - UI Objects
    weak var loginButton: RoundedButton!
    weak var signUpButton: RoundedButton!
    weak var titleLabel: UILabel!
    weak var logoImageView: UIImageView!
    
    // MARK: - Properties
    var container = AppContainer.container
    
    // MARK: - Life cycle
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.loginButton.addTarget(self, action: #selector(self.showLoginScreen), for: UIControlEvents.touchUpInside)
        self.signUpButton.addTarget(self, action: #selector(self.showSignUpScreen), for: UIControlEvents.touchUpInside)
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        self.navigationController?.navigationBar.isHidden = true
    }
    
    override init() {
        super.init()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func loadView() {
        super.loadView()
        self.setupUI()
    }
    
    // MARK: - Action methods
    /// Push transition to login screen
    @objc private func showLoginScreen() {
        guard let loginVc = container.resolve(LoginViewController.self) else { return }
        self.navigationController?.pushViewController(loginVc, animated: true)
    }
    
    /// Push transition to sign up screen
    @objc private func showSignUpScreen() {
        guard let loginVc = container.resolve(SignUpViewController.self) else { return }
        self.navigationController?.pushViewController(loginVc, animated: true)
    }
}
