//
//  LoginViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Controller for handling login screen
class LoginViewController: BaseViewController {
    
    // MARK: - UI Objects
    weak var emailTextField: UITextField!
    weak var passwordsTextField: UITextField!
    weak var loginButton: RoundedButton!
    
    // MARK: - Properties
    private var viewModel: AuthViewModeling
    
    // MARK: - Life cycle
    override func viewDidLoad() {
        super.viewDidLoad()
        self.loginButton.addTarget(self, action: #selector(self.didPressLogin), for: UIControlEvents.touchUpInside)
        self.title = "Login"
        
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        self.navigationController?.navigationBar.isHidden = false
    }
    
    required init(viewModel: AuthViewModeling) {
        
        self.viewModel = viewModel
        
        super.init()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    /// Methods which handle setting up the UI using SnapKit framework
    override func loadView() {
        super.loadView()
        
        
        let emailTextField = UITextField()
        emailTextField.delegate = self
        emailTextField.tag = 0
        emailTextField.returnKeyType = .next
        emailTextField.placeholder = "Email address:"
        emailTextField.layer.borderWidth = 1
        emailTextField.layer.cornerRadius = 4
        emailTextField.layer.borderColor = UIColor.init(color: .orangeff).cgColor
        // TODO: - Remove after tests
        emailTextField.text = "Nooxly93@gmail.com"
        self.view.addSubview(emailTextField)
        emailTextField.snp.makeConstraints { (make) in
            make.top.equalTo(view.safeAreaLayoutGuide.snp.top).offset(16)
            make.leading.equalTo(24)
            make.trailing.equalTo(-24)
            make.height.equalTo(54)
        }
        let emailPaddingView = UIView(frame: CGRect(x: 0, y: 0, width: 15, height: 54))
        emailTextField.leftView = emailPaddingView
        emailTextField.leftViewMode = .always
        
        self.emailTextField = emailTextField
        
        let passwordTextField = UITextField()
        passwordTextField.delegate = self
        passwordTextField.tag = 1
        passwordTextField.returnKeyType = .send
        passwordTextField.layer.borderWidth = 1
        passwordTextField.layer.borderColor = UIColor.init(color: .orangeff).cgColor
        passwordTextField.layer.cornerRadius = 4
        passwordTextField.isSecureTextEntry = true
        passwordTextField.placeholder = "Password:"
           // TODO: - Remove after tests
        passwordTextField.text = "Veverka"
        self.view.addSubview(passwordTextField)
        passwordTextField.snp.makeConstraints { (make) in
            make.top.equalTo(emailTextField.snp.bottom).offset(20)
            make.leading.equalTo(24)
            make.trailing.equalTo(-24)
            make.height.equalTo(54)
        }
        let passwordPaddingView = UIView(frame: CGRect(x: 0, y: 0, width: 15, height: 54))
        passwordTextField.leftView = passwordPaddingView
        passwordTextField.leftViewMode = .always
        
        self.passwordsTextField = passwordTextField
    
        
        let loginButtonAttributedText = NSAttributedString(string: "Login", attributes: [NSAttributedStringKey.font: UIFont.systemFont(ofSize: 15, weight: UIFont.Weight.bold), NSAttributedStringKey.foregroundColor: UIColor.white])
        
        let loginButton = RoundedButton()
        loginButton.backgroundColor = UIColor.init(color: .orangeff)
        loginButton.setAttributedTitle(loginButtonAttributedText, for: UIControlState.normal)
        self.view.addSubview(loginButton)
        loginButton.snp.makeConstraints { (make) in
            make.top.equalTo(passwordTextField.snp.bottom).offset(40)
            make.leading.equalTo(24)
            make.trailing.equalTo(-24)
            make.height.equalTo(54)
        }
        self.loginButton = loginButton
    }

    
    // MARK: - Action methods
    /// Perform login action. If action will succeed change root controller to tabbar controller.
    @objc private func didPressLogin() {
        guard let email = self.emailTextField.text else { return }
        guard let password = self.passwordsTextField.text else { return }
        self.loginButton.startLoading()
        
        self.viewModel.login(with: email, password: password) { (response) in
            switch response {
            case .success:
                self.loginButton.stopLoading()
                let tabBarVc = AppContainer.container ~ TabBarViewController.self
                UIApplication.shared.keyWindow?.rootViewController = tabBarVc
            case .failure:
                self.loginButton.stopLoading()
               self.presentCommonErrorAlert(with: "Something went wrong", message: "Please repeat or make sure that this account doesn't exist already")
            }
        }
    }
}

extension LoginViewController: UITextFieldDelegate {
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        let textTag = textField.tag + 1
        let nextResponder = textField.superview?.viewWithTag(textTag)
        if(nextResponder != nil)
        {
            nextResponder?.becomeFirstResponder()
        }
        else {
            self.view.endEditing(true)
            self.didPressLogin()
        }
        return true
    }
}
