//
//  ProfileViewController.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Controller which handle profile view
class ProfileViewController: BaseViewController {
    
    // MARK: - UI Objects
    weak var tableView: UITableView!
    
    // MARK: - Properties
    let viewModel: AuthViewModeling
    
    // MARK: - Life cycle
    required init(viewModel: AuthViewModeling) {
        
        self.viewModel = viewModel
        super.init()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.tableView.delegate = self
        self.tableView.dataSource = self
        self.tableView.separatorStyle = .none
        self.tableView.rowHeight = UITableViewAutomaticDimension
        self.tableView.estimatedRowHeight = 70
    }
    
    override func loadView() {
        super.loadView()
        
        let tableView = UITableView()
        tableView.backgroundColor = UIColor.init(color: .backgroundGray)
        self.view.addSubview(tableView)
        tableView.snp.makeConstraints { (make) in
            make.top.equalTo(view.safeAreaLayoutGuide.snp.top).offset(16)
            make.leading.trailing.bottom.equalTo(0)
        }
        self.tableView = tableView
    }
    
}

// MARK: - Extension for UITableViewDataSource, UITableViewDelegate
extension ProfileViewController: UITableViewDataSource, UITableViewDelegate {
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        switch (indexPath.section, indexPath.row) {
        case (0,0):
            let cell: ProfileInfoTableViewCell = tableView.dequeCellForIndexPath(indexPath: indexPath)
            cell.setupCell(with: StorageHelper.user)
            return cell
        case (1,0):
            let cell: ProfileCommonTableViewCell = tableView.dequeCellForIndexPath(indexPath: indexPath)
            cell.setupLabel(with: "About Us")
            return cell
        default:
            let cell: ProfileCommonTableViewCell = tableView.dequeCellForIndexPath(indexPath: indexPath)
            cell.setupLabel(with: "Logout")
            return cell
        }
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        switch section {
        case 0:
            return 1
        default:
            return 2
        }
    }
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        if indexPath.section == 1 {
            if indexPath.row == 0 {
                 let aboutUsVc = AppContainer.container ~ AboutUsViewController.self
                self.navigationController?.pushViewController(aboutUsVc, animated: true)
            }
            if indexPath.row == 1 {
                self.viewModel.signOut(with: { (response) in
                    switch response {
                    case .success:
                        let getStartedVc = NavigationViewController(rootViewController: AppContainer.container ~ GetStartedViewController.self)
                         UIApplication.shared.keyWindow?.rootViewController = getStartedVc
                    case .failure:
                        self.presentCommonErrorAlert(with: "Something went wrong", message: "Please repeat")
                    }
                })
            }
        }
    }
}
