//
//  AppContainer.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation
import Swinject
import KeychainSwift

infix operator ~ : ComparisonPrecedence

func ~ <Service>(lhs:Resolver, rhs:Service.Type) -> Service {
    return lhs.resolve(rhs)!
}

/// Swinject container for handling initialization of all controllers, models and required services with theirs dependecies.
class AppContainer {
    
    static let container = Container()
   
    class func mainRegister() {
        
        // MARK: - Others
        
        container.register(KeychainSwift.self) { (_) in
            KeychainSwift()
            }.inObjectScope(.container)
        
        // MARK: - Services
        container.register(AuthServicing.self) { r in
            AuthService(databaseService:  r.resolve(DatabaseFetchServicing.self)!)
        }
    
        
        container.register(DatabaseFetchServicing.self) { _ in
            DatabaseFetchService()
        }
        
        
        // MARK: - ViewModels
        container.register(AuthViewModeling.self) { r in
            AuthViewModel(authService: r.resolve(AuthServicing.self)!)
        }
        
        container.register(VaccineModeling.self) { r in
            VaccineModel(databaseService:  r.resolve(DatabaseFetchServicing.self)!)
            }.inObjectScope(.container)
        
        // MARK: - Controllers
        
        container.register(DatePickerViewController.self) { _ in
            DatePickerViewController()
        }
        
        container.register(TabBarViewController.self) { _ in
            TabBarViewController()
        }
        
        container.register(HomeViewController.self) { r in
            HomeViewController(viewModel: r ~ VaccineModeling.self)
        }
        
        container.register(LoginViewController.self) { r in
            LoginViewController(viewModel: r ~ AuthViewModeling.self)
        }
        
        container.register(ProfileViewController.self) { r in
            ProfileViewController(viewModel: r ~ AuthViewModeling.self)
        }
        
        container.register(DetailViewController.self) { _ in
            DetailViewController()
        }
        
        container.register(NewVaccineViewController.self) { r in
            NewVaccineViewController(viewModel: r ~ VaccineModeling.self)
        }
        
        container.register(SignUpViewController.self) { r in
            SignUpViewController(viewModel: r ~ AuthViewModeling.self)
        }
        
        container.register(GetStartedViewController.self) { _ in
            GetStartedViewController()
        }
        
        container.register(NavigationViewController.self) { _ in
            NavigationViewController()
        }
        
        container.register(AboutUsViewController.self) { _ in
            AboutUsViewController()
        }
    }
}
