//
//  User.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 04.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation
import SwiftyJSON

/// Model struct for User
struct User {
    let id: String
    let firstName: String
    let lastName: String
    let email: String
    let vaccineArray: [VaccineRecord]?
    
    /// Common init with know values
    init(id: String, firstName: String, lastName: String, email: String, vaccineArray: [VaccineRecord]? ) {
        self.id = id
        self.firstName = firstName
        self.lastName = lastName
        self.email = email
        self.vaccineArray = vaccineArray
    }
    
    /// Init with json object and user Id
    ///
    /// - Parameters:
    ///   - json: JSON object retrieved from database / api
    ///   - id: User Id for what we need to retrieve the values
    init(with json: JSON, id: String) {
        self.id = id
        self.firstName = json["firstName"].stringValue
        self.lastName = json["lastName"].stringValue
        self.email = json["email"].stringValue
        let jsonArray = json["vaccineArray"].arrayValue
        var vaccineArray = [VaccineRecord]()
        for vaccineRecord in jsonArray {
            let id = vaccineRecord["vaccineId"].intValue
            let vaccinationDate = DateHelper.dateFromAPI(string: vaccineRecord["vaccinationDate"].stringValue)
            let record = VaccineRecord(vaccineId: id, vaccinationDate: vaccinationDate)
            vaccineArray.append(record)
        }
        self.vaccineArray = vaccineArray
    }
    
    /// Store the user via StorageHelper to keychain
    func store() {
        StorageHelper.store(user: self)
    }
    
    /// Set the value of User object into dictionary which can be written to database as JSON
    ///
    /// - Returns: [String: Any] Dictionary of User properties values
    func toParameters() -> [String: Any] {
        
        var vaccineArrayToReturn = [[String: Any]]()
        if let array = self.vaccineArray {
            for record in array {
                vaccineArrayToReturn.append(record.toParameters())
            }
        }
        
        let toReturn = [
            "firstName": self.firstName,
            "lastName": self.lastName,
            "email":self.email,
            "vaccineArray": vaccineArrayToReturn
            ] as [String : Any]
        
        return toReturn
    }
}
