//
//  DatabaseFetchService.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 04.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation
import FirebaseDatabase
import SwiftyJSON

/// Lowest layer service. Create connection to firebase database.
protocol DatabaseFetchServicing {
    /// Write given user to database. Everytime this method is called the user for given ID is overriten by this input.
    ///
    /// - Parameter user: User to store
    /// - Returns: Void
    func writeUserToDatabase(user: User)
    
    /// Get data for given userId from database. This method is observing the database changes from the time of first call. Everytime when there is a change in the database this change is projectet in real time.
    ///
    /// - Parameters:
    ///   - userId: User id to specify the required user
    ///   - completion: Completion return the user fetched from database.
    /// - Returns: Void
    func getUserDataFromDatabase(for userId: String, completion: @escaping (_ response: User) -> Void)
    
    /// Get all vaccines from database. This method is observing the database changes from the time of first call. Everytime when there is a change in the database this change is projectet in real time.
    ///
    /// - Parameter completion: Completion return the Vaccine object array.
    func getVaccinesDataFromDatabase(completion: @escaping (_ response: [Vaccine]) -> Void)
}

class DatabaseFetchService: DatabaseFetchServicing {
    var databaseReference: DatabaseReference = Database.database().reference()
    
    // TODO: - Need completion block
    func writeUserToDatabase(user: User) {
        let userParams = user.toParameters()
       databaseReference.child("users").child(user.id).setValue(userParams)
    }
    
    func getUserDataFromDatabase(for userId: String, completion: @escaping (_ response: User) -> Void) {
        databaseReference.observe(.value) { (snapshot) in
            let jsonObj = JSON(snapshot.value as Any)
            let userJson = JSON(jsonObj["users"][userId])
            let user = User(with: userJson, id: userId)
            completion(user)
        }
    }
    
    func getVaccinesDataFromDatabase(completion: @escaping ([Vaccine]) -> Void) {
        databaseReference.observe(.value) { (snapshot) in
            let jsonObj = JSON(snapshot.value as Any)
            let vaccineJsonArray = jsonObj["vaccines"].arrayValue
            
            var toReturn = [Vaccine]()
            
            for vaccine in vaccineJsonArray {
                toReturn.append(Vaccine.init(with: vaccine))
            }
            
            completion(toReturn)
        }
    }
    
}

