//
//  StorageHelper.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 04.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation
import KeychainSwift

/// Manager that handle saving information to keychain
struct StorageHelper {
    
    private static let kUserUID = "userUID"
    private static let kUserFirstName = "firstname"
    private static let kUserLastName = "lastname"
    private static let kUserMail = "email"
   
    /// Keychain object from KaychainSwift framework
    private static var keychain:KeychainSwift {
        return AppContainer.container ~ KeychainSwift.self
    }
    
    /// Store data for given user to keychain
    ///
    /// - Parameter user: User to store
    static func store(user:User) {
        keychain.set(user.firstName, forKey: kUserFirstName)
        keychain.set(user.lastName, forKey: kUserLastName)
        keychain.set(user.id, forKey: kUserUID)
        keychain.set(user.email, forKey: kUserMail)
    }
    
    /// Delete users information from keychain. Reccomended to use during the logout
    static func deleteUserInformations() {
        keychain.delete(kUserFirstName)
        keychain.delete(kUserLastName)
        keychain.delete(kUserUID)
        keychain.delete(kUserMail)
    }
    
    /// Store user initialized from stored informations
    static var user:User? {
        guard let firstName = keychain.get(kUserFirstName), let lastName = keychain.get(kUserLastName), let id = keychain.get(kUserUID), let email = keychain.get(kUserMail) else {
            return nil
        }
        
        return User(id: id, firstName: firstName, lastName: lastName, email: email, vaccineArray: [])
    }
}
