//
//  AuthViewModel.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 04.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation

protocol AuthViewModeling {
    /// Method wrapping signUp method from authService.
    ///
    /// - Parameters:
    ///   - email: Users email
    ///   - password: Users password
    ///   - firstName: Users first name
    ///   - lastName: Users last name
    ///   - completion: Common completion block for Success or Failure
    /// - Returns: Void
    func signUp(with email: String, password: String, firstName: String, lastName: String, completion: @escaping (_ response: CommonResponse) -> Void)
    
    /// Method wrapping login method from authService
    ///
    /// - Parameters:
    ///   - email: Users email
    ///   - password: Users password
    ///   - completion: Common completion block for Success or Failure
    /// - Returns: Void
    func login(with email: String, password: String, completion: @escaping (_ response: CommonResponse) -> Void)
    
    /// Method wrapping signOut method from authService
    ///
    /// - Parameter completion: Common completion block for Success or Failure
    func signOut(with completion: @escaping (_ response: CommonResponse) -> Void)
}

class AuthViewModel: AuthViewModeling {
    
    private let authService: AuthServicing
    
    required init(authService: AuthServicing) {
        self.authService = authService
    }
    
    func signUp(with email: String, password: String, firstName: String, lastName: String, completion: @escaping (_ response: CommonResponse) -> Void) {
        self.authService.signUp(with: email, password: password, firstName: firstName, lastName: lastName, completion: completion)
    }
    func login(with email: String, password: String, completion: @escaping (_ response: CommonResponse) -> Void) {
        self.authService.login(with: email, password: password, completion: completion)
    }
    func signOut(with completion: @escaping (CommonResponse) -> Void) {
        self.authService.signOut(with: completion)
    }
}
