//
//  ProfileInfoTableViewCell.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 06.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Cell for profile informations
class ProfileInfoTableViewCell: UITableViewCell {
    
    // MARK: - UI Objects
    weak var profileImageView: UIImageView!
    weak var nameLabel: UILabel!
    weak var emailLabel: UILabel!

    // MARK: - Life cycle
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override init(style: UITableViewCellStyle, reuseIdentifier: String?) {
        
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        
        self.backgroundColor = UIColor.init(color: .backgroundGray)
        self.selectionStyle = .none
        
        let contentView = UIView()
        contentView.backgroundColor = .white
        contentView.layer.cornerRadius = 4
        self.addSubview(contentView)
        contentView.snp.makeConstraints { (make) in
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.top.equalTo(4)
            make.bottom.equalTo(-4)
        }
        
        let profileImageView = UIImageView()
        profileImageView.image = #imageLiteral(resourceName: "profilePlaceholder").withRenderingMode(.alwaysTemplate)
        profileImageView.backgroundColor = UIColor.init(color: .backgroundGray)
        profileImageView.layer.cornerRadius = 4
        profileImageView.tintColor = UIColor.init(color: .orangeff)
        contentView.addSubview(profileImageView)
        profileImageView.snp.makeConstraints { (make) in
            make.top.equalTo(8)
            make.leading.equalTo(16)
            make.size.equalTo(60)
            make.centerY.equalTo(contentView)
            //make.bottom.equalTo(8)
        }
        self.profileImageView = profileImageView
        
        let nameLabel = UILabel()
        nameLabel.font = UIFont.systemFont(ofSize: 17, weight: UIFont.Weight.bold)
        nameLabel.textAlignment = .center
        nameLabel.textColor = .black
        nameLabel.numberOfLines = 0
        contentView.addSubview(nameLabel)
        nameLabel.snp.makeConstraints { (make) in
            make.top.equalTo(8)
            make.leading.equalTo(profileImageView.snp.trailing).offset(8)
            make.trailing.equalTo(-16)
            make.height.greaterThanOrEqualTo(30)
        }
        self.nameLabel = nameLabel
        
        let emailLabel = UILabel()
        emailLabel.font = UIFont.systemFont(ofSize: 17, weight: UIFont.Weight.bold)
        emailLabel.textAlignment = .center
        emailLabel.textColor = .black
        emailLabel.numberOfLines = 0
        contentView.addSubview(emailLabel)
        emailLabel.snp.makeConstraints { (make) in
            make.top.equalTo(nameLabel.snp.bottom).offset(8)
            make.leading.equalTo(profileImageView.snp.trailing).offset(8)
            make.trailing.equalTo(-16)
            make.bottom.equalTo(-8)
            make.height.greaterThanOrEqualTo(30)
        }
        self.emailLabel = emailLabel
        
    }

    // Mark: - Setup methods
    /// Setup cell with given user
    func setupCell(with user: User?) {
        guard let user = user else { return }
        self.nameLabel.text = "\(user.firstName) \(user.lastName)"
        self.emailLabel.text = user.email
    }
}
