//
//  VaccineTableViewCell.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 10.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import UIKit

/// Cell for home view. Display all desired information about vaccination
class VaccineTableViewCell: UITableViewCell {
    
    // MARK: - UI Objects
    weak var nameLabel: UILabel!
    weak var desciptionLabel: UILabel!
    weak var dateLabel: UILabel!

    // MARK: - Life cycle
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override init(style: UITableViewCellStyle, reuseIdentifier: String?) {
        
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        
        self.backgroundColor = UIColor.init(color: .backgroundGray)
        self.selectionStyle = .none
        
        let contentView = UIView()
        contentView.backgroundColor = .white
        contentView.layer.cornerRadius = 4
        self.addSubview(contentView)
        contentView.snp.makeConstraints { (make) in
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.top.equalTo(4)
            make.bottom.equalTo(-4)
        }
        
        let nameLabel = UILabel()
        nameLabel.textAlignment = .left
        nameLabel.numberOfLines = 0
        nameLabel.font = UIFont.systemFont(ofSize: 16, weight: UIFont.Weight.bold)
        nameLabel.textColor = .black
        contentView.addSubview(nameLabel)
        nameLabel.snp.makeConstraints { (make) in
            make.top.equalTo(8)
            make.leading.equalTo(8)
            make.trailing.equalTo(-8)
        }
        
        self.nameLabel = nameLabel
        
        let descriptionLabel = UILabel()
        descriptionLabel.textAlignment = .left
        descriptionLabel.numberOfLines = 0
        descriptionLabel.font = UIFont.systemFont(ofSize: 14, weight: UIFont.Weight.medium)
        descriptionLabel.textColor = .black
        contentView.addSubview(descriptionLabel)
        descriptionLabel.snp.makeConstraints { (make) in
            make.top.equalTo(nameLabel.snp.bottom).offset(8)
            make.leading.equalTo(8)
            make.trailing.equalTo(-8)
        }
        self.desciptionLabel = descriptionLabel
        
        let dateLabel = UILabel()
        dateLabel.textAlignment = .left
        dateLabel.numberOfLines = 0
        dateLabel.font = UIFont.systemFont(ofSize: 14, weight: UIFont.Weight.medium)
        dateLabel.textColor = .black
        contentView.addSubview(dateLabel)
        dateLabel.snp.makeConstraints { (make) in
            make.top.equalTo(descriptionLabel.snp.bottom).offset(8)
            make.leading.equalTo(8)
            make.trailing.bottom.equalTo(-8)
        }
        
        self.dateLabel = dateLabel
    }
    
    // MARK: - Setup methods
    /// Setup cell with given Vaccine object.
    func setupCell(with vaccine: Vaccine) {
        self.nameLabel.text = vaccine.name
        self.desciptionLabel.text = vaccine.description
        let dateString = DateHelper.stringFromAPI(date: vaccine.vaccinationDate ?? Date())
        self.dateLabel.text = "Date for vaccination: \(dateString).\nRevaccination in: \(vaccine.revaccinationInYears) years"
    }
}
