//
//  RoundedButton.swift
//  VakcinaDP
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import Foundation
import UIKit

/// Custom button class with certain formatting and rounded corners.
class RoundedButton: LoadingButton {
    
    // MARK: - Life cycle
    override init(frame: CGRect) {
        super.init(frame: frame)
    }
    
    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
        
    }
    override func layoutSubviews() {
        super.layoutSubviews()
        self.makeRounded()
        
    }
    
    // MARK: - Setup methods
    /// Method for setup button with given parameters
    ///
    /// - Parameters:
    ///   - backgroundColor: Background color of the button
    ///   - titleText: Title for the button
    ///   - borderColor: Border collor for button if there is need for any
    ///   - titleTextColor: Title color for button
    ///   - titleFont: Font for button
    func setupRoundedButton(backgroundColor: UIColor, titleText: String, borderColor: UIColor?, titleTextColor: UIColor, titleFont: UIFont) {
        self.backgroundColor = backgroundColor
        let attributedText = NSAttributedString(string: titleText, attributes: [NSAttributedStringKey.font: titleFont, NSAttributedStringKey.foregroundColor: titleTextColor])
        self.setAttributedTitle(attributedText, for: .normal)
        if let borderColor = borderColor {
            self.layer.borderWidth = 1
            self.layer.borderColor = borderColor.cgColor
        } else {
            self.layer.borderWidth = 0
        }
    }
    
    /// Make rounded corners
    func makeRounded(){
        self.layer.cornerRadius = self.frame.height / 2
    }

}
