//
//  VakcinaDPTests.swift
//  VakcinaDPTests
//
//  Created by Thomas Hamerník on 03.02.18.
//  Copyright © 2018 Thomas Hamerník. All rights reserved.
//

import XCTest
import SwiftyJSON
@testable import VakcinaDP

class VakcinaDPTests: XCTestCase {
    
    var userUnderTest: User!
    
    override func setUp() {
        super.setUp()
        do {
        try self.testUserJSONMapping()
        } catch {
            XCTFail("Mapping failed")
        }
        // Put setup code here. This method is called before the invocation of each test method in the class.
    }
    
    /// Test user json parsing from mock json file saved locally.
    func testUserJSONMapping() throws {
        guard let url = Bundle.main.url(forResource: "userMock", withExtension: "json") else {
            XCTFail("Missing file: userMock.json")
            return
        }
        
        let data = try Data(contentsOf: url)
        let json = JSON(data)

        self.userUnderTest = User(with: json, id: "someUserId")
    
        XCTAssertEqual(self.userUnderTest.email, "Nooxly93@gmail.com")
        XCTAssertEqual(self.userUnderTest.vaccineArray?.last?.vaccineId, 0)
    }
    
    /// Test converting user values into dictionary [String: Any] which is used to convert to JSON and write data to database.
    func testUserToParameters() {
        let parametersDict = self.userUnderTest.toParameters()
        XCTAssertEqual(parametersDict["firstName"] as! String, "Tomáš")
    }
    
    /// Test sorting vaccine values retrieved for given user.
    func testVaccinationSort() {
        
        let databaseService = DatabaseFetchService()
        let vaccine1 = Vaccine(id: 0, name: "Chřipka", description: "lorem ipsum", revaccinationInYears: 10, vaccinationDate: nil)
        let vaccine2 = Vaccine(id: 1, name: "Žloutenka", description: "lorem ipsum", revaccinationInYears: 3, vaccinationDate: nil)
        let vaccines = [vaccine1, vaccine2]
        
        let viewModel = VaccineModel(databaseService: databaseService)
        let testTuple = viewModel.vaccineSort(with: self.userUnderTest, vaccines: vaccines)
        
          XCTAssertEqual(testTuple.finished.count, 2)
        XCTAssertEqual(testTuple.pending.count, 2)
    
    }
    
    override func tearDown() {
        // Put teardown code here. This method is called after the invocation of each test method in the class.
        super.tearDown()
    }
    
    func testPerformanceExample() {
        // This is an example of a performance test case.
        self.measure {
    
        }
    }
    
}
